@@ -19,13 +19,15 @@
 
 """Utility functions tests"""
 
-from pygal._compat import u, _ellipsis
-from pygal.util import (
-    round_to_int, round_to_float, _swap_curly, template,
-    truncate, minify_css, majorize, mergextend)
-from pytest import raises
 import sys
 
+from pytest import raises
+
+from pygal._compat import _ellipsis, u
+from pygal.util import (
+    _swap_curly, majorize, mergextend, minify_css, round_to_float,
+    round_to_int, template, truncate)
+
 
 def test_round_to_int():
     """Test round to int function"""
